@@ -176,7 +176,14 @@ public:
   void SetZoomFactor(double newzoom);
 
   //! Sets the zoom factor without storing the new value in the config file/registry.
-  void SetZoomFactor_temporarily(double newzoom){m_zoomFactor = newzoom;}
+  void SetZoomFactor_temporarily(double newzoom){
+    if(m_zoomFactor != newzoom)
+    {
+      RecalculationForce(true);
+      FontChanged(true);
+    }
+    m_zoomFactor = newzoom;
+  }
 
   /*! Scales a distance [in pixels] according to the zoom factor
 
@@ -231,12 +238,14 @@ public:
 
   void ReadStyle();
 
-  void SetForceUpdate(bool force)
+  //! Force a full recalculation?
+  void RecalculationForce(bool force)
   {
     m_forceUpdate = force;
   }
 
-  bool ForceUpdate()
+  //! Force a full recalculation?
+  bool RecalculationForce()
   {
     return m_forceUpdate;
   }
@@ -290,12 +299,32 @@ public:
     Normallly this parameter is automatically calculated
    */
   void SetIndent(int indent)
-  { m_indent = indent; }
+  {
+    if(m_indent != indent)
+      RecalculationForce(true);
+    m_indent = indent;
+  }
 
   //! Set the width of the visible window for GetClientWidth()
   void SetClientWidth(int width)
-  { m_clientWidth = width; }
-
+  {
+    if(m_clientWidth != width)
+      RecalculationForce(true);
+    m_clientWidth = width;
+  }
+  //! Has a font changed?
+  bool FontChanged(){return m_fontChanged;}
+  WX_DECLARE_STRING_HASH_MAP( bool, CharsInFontMap);
+  CharsInFontMap m_charsInFontMap;
+  //! Has a font changed?
+  void FontChanged(bool fontChanged)
+    {
+      m_fontChanged = fontChanged;
+      if(fontChanged)
+        RecalculationForce(true);
+      m_charsInFontMap.clear();
+    }
+  
   //! Set the height of the visible window for GetClientHeight()
   void SetClientHeight(int height)
   { m_clientHeight = height; }
@@ -319,9 +348,14 @@ public:
 
   //! The minimum sensible line width in withs of a letter.
   int LineWidth_em()
-  { return m_lineWidth_em; }
+  {
+    if(!m_printing)
+      return m_lineWidth_em;
+    else
+      return 10000;
+  }
 
-  //! Set the minimum sensible line width in widths of a lletter.
+  //! Set the minimum sensible line width in widths of a letter.
   void LineWidth_em(int width)
   { m_lineWidth_em = width; }
 
@@ -332,7 +366,7 @@ public:
   {
     if (
       (m_clientWidth <= m_zoomFactor * double(m_defaultFontSize) * LineWidth_em() * m_zoomFactor) ||
-      (m_printer)
+      (m_printing)
       )
       return m_clientWidth;
     else
@@ -412,11 +446,27 @@ public:
 
   void ShowCodeCells(bool show);
 
-  void SetPrinter(bool printer)
-  { m_printer = printer; }
+  /*! Are we currently printing?
 
-  bool GetPrinter()
-  { return m_printer; }
+    This affects the bitmap scale as well as the fact if we want
+    to output objects that are outside the region that currently is
+    redrawn.
+  */
+  void SetPrinting(bool printing)
+    {
+      m_printing = printing;
+      if(printing)
+        ClipToDrawRegion(false);
+    }
+
+  /*! Are we currently printing?
+
+    This affects the bitmap scale as well as the fact if we want
+    to output objects that are outside the region that currently is
+    redrawn.
+  */
+  bool GetPrinting()
+  { return m_printing; }
 
   bool GetMatchParens()
   { return m_matchParens; }
@@ -450,7 +500,9 @@ public:
     wxASSERT_MSG(displayedDigits >= 20, _("Bug: Maximum number of digits that is to be displayed is too low!"));
     wxConfig::Get()->Write(wxT("displayedDigits"), m_displayedDigits = displayedDigits);
   }
-
+  
+  wxRect GetUpdateRegion(){return m_updateRegion;}
+  void SetUpdateRegion(wxRect rect){m_updateRegion = rect;}
   bool GetInsertAns()
   { return m_insertAns; }
 
@@ -595,9 +647,9 @@ public:
   int ShowLength(){return m_showLength;}
 
   //! Sets the default toolTip for new cells
-  void SetDefaultMathCellToolTip(wxString defaultToolTip){m_defaultToolTip = defaultToolTip;}
+  void SetDefaultCellToolTip(wxString defaultToolTip){m_defaultToolTip = defaultToolTip;}
   //! Gets the default toolTip for new cells
-  wxString GetDefaultMathCellToolTip(){return m_defaultToolTip;}
+  wxString GetDefaultCellToolTip(){return m_defaultToolTip;}
   //! Which way do we want to draw parenthesis?
   void SetGrouphesisDrawMode(drawMode mode){m_parenthesisDrawMode = mode;}
 
@@ -647,7 +699,24 @@ public:
   wxString GetAutosubscript_string();
   //! Determine the default background color of the worksheet
   wxColor DefaultBackgroundColor(){return m_defaultBackgroundColor;}
+  //! Do we want to save time by only redrawing the area currently shown on the screen?
+  bool ClipToDrawRegion(){return m_clipToDrawRegion;}
+  //! Do we want to save time by only redrawing the area currently shown on the screen?
+  void ClipToDrawRegion(bool clipToDrawRegion){m_clipToDrawRegion = clipToDrawRegion; m_forceUpdate = true;}
+  //! Request adjusting the worksheet size?
+  void AdjustWorksheetSize(bool adjust)
+    { m_adjustWorksheetSizeNeeded = adjust; }
+  bool AdjustWorksheetSize()
+    { return m_adjustWorksheetSizeNeeded; }
+  void SetVisibleRegion(wxRect visibleRegion){m_visibleRegion = visibleRegion;}
+  wxRect GetVisibleRegion(){return m_visibleRegion;}
+  void SetWorksheetPosition(wxPoint worksheetPosition){m_worksheetPosition = worksheetPosition;}
+  wxPoint GetWorksheetPosition(){return m_worksheetPosition;}
 private:
+  //! The worksheet all cells are drawn on
+  wxRect m_updateRegion;
+  //! Has the font changed?
+  bool m_fontChanged;
   /*! The interval between auto-saves (in milliseconds). 
 
     Values <10000 mean: Auto-save is off.
@@ -718,6 +787,7 @@ private:
   int m_defaultFontSize, m_mathFontSize;
   wxString m_mathFontName;
   bool m_forceUpdate;
+  bool m_clipToDrawRegion;
   bool m_outdated;
   wxString m_defaultToolTip;
   bool m_TeXFonts;
@@ -728,7 +798,7 @@ private:
   int m_clientHeight;
   wxFontEncoding m_fontEncoding;
   style m_styles[STYLE_NUM];
-  bool m_printer;
+  bool m_printing;
   int m_lineWidth_em;
   int m_showLabelChoice;
   bool m_fixReorderedIndices;
@@ -745,6 +815,12 @@ private:
   bool m_useUnicodeMaths;
   bool m_indentMaths;
   bool m_abortOnError;
+  bool m_adjustWorksheetSizeNeeded;
+  //! The rectangle of the worksheet that is currently visible.
+  wxRect m_visibleRegion;
+  //! The position of the worksheet in the wxMaxima window
+  wxPoint m_worksheetPosition;
+
   wxColour m_defaultBackgroundColor;
 };
 
