@@ -25,6 +25,7 @@
  */
 
 #include "EMFout.h"
+#include "ErrorRedirector.h"
 #include <wx/txtstrm.h>
 #include <wx/filename.h>
 #include <wx/wfstream.h>
@@ -60,8 +61,8 @@ Emfout::Emfout(Configuration **configuration, wxString filename)
   // usable. Also the probability was high that the right font wasn't
   // available in inkscape.
   (*m_configuration)->SetGrouphesisDrawMode(Configuration::handdrawn);
-  MathCell::ClipToDrawRegion(false);
-  (*m_configuration)->SetForceUpdate(true);
+  (*m_configuration)->ClipToDrawRegion(false);
+  (*m_configuration)->RecalculationForce(true);
 }
 
 Emfout::~Emfout()
@@ -78,14 +79,16 @@ Emfout::~Emfout()
   {
     // We don't want a braindead virus scanner that disallows us to delete our temp
     // files to trigger asserts.
+    SuppressErrorDialogs messageBlocker;
+    
     wxRemoveFile(m_tempFileName);
   }
   *m_configuration = m_oldconfig;
-  MathCell::ClipToDrawRegion(true);
-  (*m_configuration)->SetForceUpdate(false);
+  (*m_configuration)->FontChanged(true);
+  (*m_configuration)->RecalculationForce(true);
 }
 
-wxSize Emfout::SetData(MathCell *tree)
+wxSize Emfout::SetData(Cell *tree)
 {
   wxDELETE(m_tree);
   m_tree = tree;
@@ -168,7 +171,7 @@ void Emfout::RecalculateHeight()
   wxConfig::Get()->Read(wxT("fontSize"), &fontsize);
   int mfontsize = fontsize;
   wxConfig::Get()->Read(wxT("mathfontsize"), &mfontsize);
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
 
   while (tmp != NULL)
   {
@@ -183,7 +186,7 @@ void Emfout::RecalculateWidths()
   wxConfig::Get()->Read(wxT("fontSize"), &fontsize);
   int mfontsize = fontsize;
   wxConfig::Get()->Read(wxT("mathfontsize"), &mfontsize);
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
 
   while (tmp != NULL)
   {
@@ -197,7 +200,7 @@ void Emfout::BreakLines()
   int fullWidth = 500;
   int currentWidth = 0;
 
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
 
   while (tmp != NULL)
   {
@@ -220,7 +223,7 @@ void Emfout::BreakLines()
 
 void Emfout::GetMaxPoint(int *width, int *height)
 {
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
   int currentHeight = 0;
   int currentWidth = 0;
   *width = 0;
@@ -254,7 +257,7 @@ void Emfout::GetMaxPoint(int *width, int *height)
 
 void Emfout::Draw()
 {
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
 
   if (tmp != NULL)
   {
@@ -328,6 +331,11 @@ Emfout::EMFDataObject *Emfout::GetDataObject()
   }
   if((m_filename != wxEmptyString) && (wxFileExists(m_filename)))
   {
+    // Don't output error messages if the worst thing that can happen is that we
+    // cannot clean up a temp file
+
+    SuppressErrorDialogs messageBlocker;
+
     wxRemoveFile(m_filename);
   }
   m_filename = wxEmptyString;
@@ -350,7 +358,7 @@ bool Emfout::ToClipboard()
 
 void Emfout::BreakUpCells()
 {
-  MathCell *tmp = m_tree;
+  Cell *tmp = m_tree;
   int fontsize = 12;
   wxConfig::Get()->Read(wxT("fontSize"), &fontsize);
   int mfontsize = fontsize;
