@@ -19,6 +19,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
+//  SPDX-License-Identifier: GPL-2.0+
 
 /*! \file
   This file defines the class EvaluationQueue
@@ -59,7 +60,7 @@ bool EvaluationQueue::IsInQueue(GroupCell *gr)
 
 void EvaluationQueue::Remove(GroupCell *gr)
 {
-  bool removeFirst = m_queue.size() > 0 && gr == m_queue.front();
+  bool removeFirst = !(m_queue.empty()) && gr == m_queue.front();
   m_queue.remove(gr);
   m_size = m_queue.size();
   if(removeFirst)
@@ -70,7 +71,7 @@ void EvaluationQueue::Remove(GroupCell *gr)
   }
 }
 
-void EvaluationQueue::AddToQueue(GroupCell *gr)
+void EvaluationQueue::AddToQueue(GroupCell *gr, bool lispMode)
 {
   if(gr == NULL)
     return;
@@ -78,8 +79,9 @@ void EvaluationQueue::AddToQueue(GroupCell *gr)
   if (gr->GetGroupType() != GC_TYPE_CODE
       || gr->GetEditable() == NULL) // don't add cells which can't be evaluated
     return;
-
-  gr->GetEditable()->AddEnding();
+  
+  if(!lispMode)
+    gr->GetEditable()->AddEnding();
 
   if(m_queue.empty())
   {
