@@ -25,7 +25,7 @@
 /*! \file
   This file defines the class GroupCell
 
-  GroupCell is the MathCell type that bundles user input with eventual images or 
+  GroupCell is the Cell type that bundles user input with eventual images or 
   output from maxima that belongs to it.
 */
 
@@ -37,10 +37,10 @@
 #include "TextCell.h"
 #include "EditorCell.h"
 #include "ImgCell.h"
-#include "Bitmap.h"
+#include "BitmapOut.h"
 #include "list"
 
-GroupCell::GroupCell(Configuration **config, int groupType, CellPointers *cellPointers, wxString initString) : MathCell(
+GroupCell::GroupCell(Configuration **config, GroupType groupType, CellPointers *cellPointers, wxString initString) : Cell(
         this, config)
 {
   m_next = m_previous = m_nextToDraw = m_previousToDraw = NULL;
@@ -49,6 +49,7 @@ GroupCell::GroupCell(Configuration **config, int groupType, CellPointers *cellPo
   m_inEvaluationQueue = false;
   m_lastInEvaluationQueue = false;
   m_inputLabel = NULL;
+  m_labelWidth_cached = 0;
   m_output = NULL;
   m_hiddenTree = NULL;
   m_hiddenTreeParent = NULL;
@@ -242,13 +243,13 @@ void GroupCell::SetCellStyle(int style)
 /*! Set the parent of this group cell
 
 */
-void GroupCell::SetGroup(MathCell *parent)
+void GroupCell::SetGroup(Cell *parent)
 {
   //m_group = parent;
   if (m_inputLabel != NULL)
     m_inputLabel->SetGroupList(parent);
 
-  MathCell *tmp = m_output;
+  Cell *tmp = m_output;
   if(m_output != NULL)
     tmp->SetGroupList(parent);
 }
@@ -287,7 +288,7 @@ void GroupCell::ResetInputLabelList()
 
 }
 
-MathCell *GroupCell::Copy()
+Cell *GroupCell::Copy()
 {
   GroupCell *tmp = new GroupCell(m_configuration, m_groupType, m_cellPointers);
   tmp->Hide(m_hide);
@@ -439,12 +440,12 @@ void GroupCell::MarkAsDeleted()
   if (this == m_cellPointers->m_groupCellUnderPointer)
     m_cellPointers->m_groupCellUnderPointer = NULL;
 
-  MathCell::MarkAsDeleted();
+  Cell::MarkAsDeleted();
 }
 
-std::list<MathCell *> GroupCell::GetInnerCells()
+std::list<Cell *> GroupCell::GetInnerCells()
 {
-  std::list<MathCell *> innerCells;
+  std::list<Cell *> innerCells;
   if (m_groupType != GC_TYPE_PAGEBREAK)
   {
     if(GetInput())
@@ -462,7 +463,7 @@ wxString GroupCell::TexEscapeOutputCell(wxString Input)
   return (Input);
 }
 
-void GroupCell::SetInput(MathCell *input)
+void GroupCell::SetInput(Cell *input)
 {
   if (input == NULL)
     return;
@@ -471,7 +472,7 @@ void GroupCell::SetInput(MathCell *input)
   m_inputLabel->SetGroup(this);
 }
 
-void GroupCell::AppendInput(MathCell *cell)
+void GroupCell::AppendInput(Cell *cell)
 {
   if (m_inputLabel == NULL)
   {
@@ -496,26 +497,24 @@ void GroupCell::AppendInput(MathCell *cell)
 }
 
 
-void GroupCell::SetOutput(MathCell *output)
+void GroupCell::SetOutput(Cell *output)
 {
-  if (output == NULL)
-    return;
-  
   if((m_cellPointers->m_answerCell) &&(m_cellPointers->m_answerCell->GetGroup() == this))
     m_cellPointers->m_answerCell = NULL;
   
   wxDELETE(m_output);
 
   m_output = output;
-  m_output->SetGroup(this);
+
 
   m_lastInOutput = m_output;
 
-  while (m_lastInOutput->m_next != NULL)
-    m_lastInOutput = m_lastInOutput->m_next;
-
-  // ResetSize();
-  //m_appendedCells = output;
+  if(m_output != NULL)
+  {
+    m_output->SetGroup(this);
+    while (m_lastInOutput->m_next != NULL)
+      m_lastInOutput = m_lastInOutput->m_next;
+  }
 }
 
 void GroupCell::RemoveOutput()
@@ -538,10 +537,16 @@ void GroupCell::RemoveOutput()
 
   ResetSize();
   RecalculateHeight((*m_configuration)->GetDefaultFontSize());
+  (*m_configuration)->AdjustWorksheetSize(true);
   m_hide = false;
+
+  // Move all cells that follow the current one up by the amount this cell has shrinked.
+  GroupCell *cell = dynamic_cast<GroupCell *>(this->m_next);
+  while(cell != NULL)
+    cell = cell->UpdateYPosition();
 }
 
-void GroupCell::AppendOutput(MathCell *cell)
+void GroupCell::AppendOutput(Cell *cell)
 {
   wxASSERT_MSG(cell != NULL, _("Bug: Trying to append NULL to a group cell."));
   if (cell == NULL) return;
@@ -561,7 +566,7 @@ void GroupCell::AppendOutput(MathCell *cell)
 
   else
   {
-    MathCell *tmp = m_lastInOutput;
+    Cell *tmp = m_lastInOutput;
     if (tmp == NULL)
       tmp = m_output;
 
@@ -577,7 +582,6 @@ void GroupCell::AppendOutput(MathCell *cell)
 
   if (m_appendedCells == NULL)
     m_appendedCells = cell;
-  // ResetSize();
 }
 
 void GroupCell::Recalculate()
@@ -593,9 +597,10 @@ void GroupCell::Recalculate()
 
 void GroupCell::RecalculateWidths(int fontsize)
 {
-  MathCell::RecalculateWidths(fontsize);
+  Cell::RecalculateWidths(fontsize);
   Configuration *configuration = (*m_configuration);
-  if (m_width == -1 || m_height == -1 || configuration->ForceUpdate())
+  
+  if (NeedsRecalculation())
   {
     // special case of 'line cell'
     if (m_groupType == GC_TYPE_PAGEBREAK)
@@ -605,47 +610,42 @@ void GroupCell::RecalculateWidths(int fontsize)
       ResetData();
       return;
     }
-
+    
     UnBreakUpCells();
 
     if(m_inputLabel != NULL)
     {
       m_inputLabel->RecalculateWidthsList(fontsize);
-      
-      // recalculate the position of input in ReEvaluateSelection!
-      // m_inputLabel->m_currentPoint.x = m_currentPoint.x;
+      m_inputLabel->SetCurrentPoint(m_currentPoint);
     }
-    
+
     if (m_output == NULL || m_hide)
     {
       if ((configuration->ShowCodeCells()) ||
           (m_groupType != GC_TYPE_CODE))
       {
-        m_width = m_inputLabel->GetFullWidth();
-      }
-      else
-        m_width = 0;
+        m_width = GetInputIndent();
+        if(GetInput())
+          m_width += GetInput()->GetWidth();
+      }  
     }
-    else    {
-      MathCell *tmp = m_output;
-      while (tmp != NULL)
-      {
-        tmp->RecalculateWidths(tmp->IsMath() ? m_mathFontSize : m_fontSize);
-        tmp = tmp->m_next;
-      }
-      // This is not correct, m_width will be computed correctly in RecalculateHeight!
+    else
+    {
       if ((configuration->ShowCodeCells()) ||
           (m_groupType != GC_TYPE_CODE))
       {
-        if(m_inputLabel != NULL)
-          m_width = m_inputLabel->GetFullWidth();
+        m_width = Scale_Px(100);
+        if(GetInput() != NULL)
+          m_width = GetInput()->GetFullWidth() + GetInputIndent();
         else
-          m_width = 100;
+        {
+            m_width = GetInputIndent();
+        }
       }
     }
 
-    BreakUpCells(m_fontSize, configuration->GetClientWidth());
-    BreakLines(configuration->GetClientWidth());
+    BreakUpCells();
+    BreakLines();
   }
   ResetData();
 }
@@ -662,9 +662,8 @@ void GroupCell::InputHeightChanged()
   if (m_inputLabel != NULL) {
     m_inputLabel->ResetData();
   }
-  RecalculateHeightInput(m_fontSize);
-  if(m_output)
-    m_height += m_output->GetMaxHeight();
+  RecalculateHeightInput();
+  RecalculateHeightOutput();
 }
 
 // Called on resize events
@@ -673,7 +672,7 @@ void GroupCell::InputHeightChanged()
 void GroupCell::OnSize()
 {
   // Unbreakup cells
-  MathCell *tmp = m_output;
+  Cell *tmp = m_output;
   while (tmp != NULL)
   {
     tmp->Unbreak();
@@ -681,13 +680,12 @@ void GroupCell::OnSize()
     tmp->ResetData();
     tmp = tmp->m_next;
   }
-  int clientWidth = (*m_configuration)->GetClientWidth();
-  BreakUpCells(m_fontSize, clientWidth);
-  BreakLines(clientWidth);
+  BreakUpCells();
+  BreakLines();
   InputHeightChanged();
 }
 
-void GroupCell::RecalculateHeightInput(int fontsize)
+void GroupCell::RecalculateHeightInput()
 {
   Configuration *configuration = (*m_configuration);
   
@@ -697,7 +695,7 @@ void GroupCell::RecalculateHeightInput(int fontsize)
     m_width = configuration->GetCellBracketWidth();
     m_height = 2;
     m_center = 0;
-    MathCell::RecalculateWidthsList(fontsize);
+    Cell::RecalculateWidthsList(m_fontSize);
     return;
   }
   
@@ -706,7 +704,7 @@ void GroupCell::RecalculateHeightInput(int fontsize)
   {
     if(m_inputLabel)
     {
-      m_inputLabel->RecalculateHeightList(fontsize);
+      m_inputLabel->RecalculateHeightList(m_fontSize);
       m_center = m_inputLabel->GetMaxCenter();
       m_height = m_inputLabel->GetMaxHeight();
     }
@@ -719,7 +717,7 @@ void GroupCell::RecalculateHeightInput(int fontsize)
   
   if (!m_hide)
   {
-    MathCell *tmp = m_output;
+    Cell *tmp = m_output;
     while (tmp != NULL)
     {
       tmp->RecalculateHeight(tmp->IsMath() ? m_mathFontSize : m_fontSize);
@@ -761,7 +759,7 @@ void GroupCell::RecalculateHeightInput(int fontsize)
   m_inputWidth = m_width;
 }
 
-void GroupCell::RecalculateHeightOutput(int WXUNUSED(fontsize))
+void GroupCell::RecalculateHeightOutput()
 {
   if(!m_hide)
   {
@@ -771,23 +769,30 @@ void GroupCell::RecalculateHeightOutput(int WXUNUSED(fontsize))
   }
 }
 
+bool GroupCell::NeedsRecalculation()
+{
+  bool result = ((m_width < 0) || (m_height < 0) ||
+                 (m_currentPoint.x < 0) || (m_currentPoint.y < 0) ||
+                 ((*m_configuration)->RecalculationForce() ||
+                  ((GetInput() != NULL) &&
+                   ((GetInput()->GetWidth() < 0) || (GetInput()->GetHeight() < 0))
+                    )));
+  return result;
+}
+
 void GroupCell::RecalculateHeight(int fontsize)
 {
-  MathCell::RecalculateHeight(fontsize);
+  Cell::RecalculateHeight(fontsize);
   Configuration *configuration = (*m_configuration);
 
-  if (m_width < 0 || m_height < 0 || m_currentPoint.x < 0 || m_currentPoint.y < 0 ||
-      configuration->ForceUpdate() || fontsize != m_fontSize_Old)
+  if(NeedsRecalculation())
   {
-    m_fontSize_Old = fontsize;
-
-    RecalculateHeightInput(fontsize);
-    
-    RecalculateHeightOutput(fontsize);
+    RecalculateHeightInput();   
+    RecalculateHeightOutput();
   }
 
-  if (((m_height != 0) || (m_next == NULL)) && (m_height < configuration->GetCellBracketWidth()))
-    m_height = configuration->GetCellBracketWidth();
+//  if (((m_height <= 0) || (m_next == NULL)) && (m_height < configuration->GetCellBracketWidth()))
+//    m_height = configuration->GetCellBracketWidth();
   
   configuration= (*m_configuration);
   if (m_previous == NULL)
@@ -814,10 +819,10 @@ void GroupCell::RecalculateHeight(int fontsize)
     m_inputLabel->SetCurrentPoint(m_currentPoint);
   if (GetEditable())
   {
-    if(m_inputLabel == NULL)
-      GetEditable()->SetCurrentPoint(m_currentPoint);
-    else
-      GetEditable()->SetCurrentPoint(wxPoint(m_currentPoint.x + m_inputLabel->GetWidth(), m_currentPoint.y));
+    wxPoint in = GetCurrentPoint();
+    
+    in.x += GetInputIndent();
+    GetEditable()->SetCurrentPoint(GetCurrentPoint());
   }
 }
 
@@ -827,10 +832,15 @@ void GroupCell::RecalculateAppended()
   if(m_hide)
     return;
   Configuration *configuration = (*m_configuration);
+  if (m_appendedCells == NULL)
+    m_appendedCells = m_inputLabel;
+  if (m_appendedCells == NULL)
+    m_appendedCells = GetInput();
   if (m_appendedCells == NULL)
     return;
+  m_appendedCells->ForceBreakLineHere();
 
-  MathCell *tmp = m_appendedCells;
+  Cell *tmp = m_appendedCells;
   m_fontSize = configuration->GetFontSize(TS_TEXT);
   m_mathFontSize = configuration->GetMathFontSize();
 
@@ -842,29 +852,30 @@ void GroupCell::RecalculateAppended()
   }
 
   // Breakup cells and break lines
-  BreakUpCells(m_appendedCells, m_fontSize, configuration->GetClientWidth());
-  BreakLines(m_appendedCells, configuration->GetClientWidth());
+  BreakUpCells(m_appendedCells);
+  BreakLines(m_appendedCells);
 
   // Recalculate size of cells
   tmp = m_appendedCells;
   while (tmp != NULL)
   {
     tmp->RecalculateHeight(tmp->IsMath() ? m_mathFontSize : m_fontSize);
+    tmp->ResetData();
     tmp = tmp->m_next;
   }
 
-  // Update widths
+  // Update heights
   tmp = m_appendedCells;
+  tmp->ForceBreakLine(true);
   while (tmp != NULL)
   {
-    if ((tmp->BreakLineHere()) ||
-        ((tmp->m_previousToDraw == NULL) && (tmp->m_nextToDraw == NULL)) ||
-        (tmp->GetStyle() == TS_LABEL) || (tmp->GetStyle() == TS_USERLABEL))
+    if (tmp->BreakLineHere())
     {
+      int height_Delta = tmp->GetMaxHeight();
       m_width = MAX(m_width, tmp->GetLineWidth());
-      m_outputRect.width = MAX(m_outputRect.width, tmp->GetLineWidth());
-      m_height            += tmp->GetMaxHeight();
-      m_outputRect.height += tmp->GetMaxHeight();
+      m_height            += height_Delta;
+      m_outputRect.width = m_width;
+      m_outputRect.height += height_Delta;
       
       if (tmp->m_previousToDraw != NULL &&
           ((tmp->GetStyle() == TS_LABEL) || (tmp->GetStyle() == TS_USERLABEL)))
@@ -883,17 +894,74 @@ void GroupCell::RecalculateAppended()
   }
 
   m_appendedCells = NULL;
+
+  ResetData();
+  
+  // Move all cells that follow the current one down by the amount this cell has grown.
+  GroupCell *cell = dynamic_cast<GroupCell *>(this->m_next);
+  while(cell != NULL)
+    cell = cell->UpdateYPosition();
+  (*m_configuration)->AdjustWorksheetSize(true);
+}
+
+GroupCell *GroupCell::UpdateYPosition()
+{
+  if (m_previous != NULL)
+  {
+    m_currentPoint.x = (*m_configuration)->GetIndent();
+    m_currentPoint = m_previous->GetCurrentPoint();
+    m_currentPoint.y += m_previous->GetMaxHeight();
+    if(m_previous->GetMaxDrop() > 0)
+      m_currentPoint.y += (*m_configuration)->GetGroupSkip();
+  }
+  return dynamic_cast<GroupCell *>(m_next);
+}
+
+int GroupCell::GetInputIndent()
+{
+  int labelWidth = 0;
+  if((*m_configuration)->IndentMaths())
+    labelWidth = Scale_Px((*m_configuration)->GetLabelWidth()) + MC_TEXT_PADDING;
+  
+  if(m_inputLabel != NULL)
+  {
+    if(m_inputLabel->GetWidth() >= 0)
+      labelWidth = MAX(m_inputLabel->GetWidth() + MC_TEXT_PADDING,labelWidth);
+    else
+      labelWidth = MAX(m_labelWidth_cached,labelWidth);
+  }
+  
+  m_labelWidth_cached = labelWidth;
+    
+  return labelWidth;
 }
 
 void GroupCell::Draw(wxPoint point)
 {
-  MathCell::Draw(point);
+  Cell::Draw(point);
+
+   // std::cerr<<"GroupCell("<<
+   //   GetRect().GetLeft()<<","<<
+   //   GetRect().GetTop()<<","<<
+   //   GetRect().GetRight()<<","<<
+   //   GetRect().GetBottom()<<"),"<<
+   //   "), UpdateRegion=("<<
+   //   (*m_configuration)->GetUpdateRegion().GetLeft()<<","<<
+   //   (*m_configuration)->GetUpdateRegion().GetTop()<<","<<
+   //   (*m_configuration)->GetUpdateRegion().GetRight()<<","<<
+   //   (*m_configuration)->GetUpdateRegion().GetBottom()<<"),"<<
+   //   DrawThisCell(point)<<!(*m_configuration)->GetUpdateRegion().Intersect(GetRect()).IsEmpty()<<"\n";
+
+  Configuration *configuration = (*m_configuration);
+
+  if (configuration->ShowBrackets())
+    DrawBracket();
+
   if (DrawThisCell(point))
   {
     if (m_width == -1 || m_height == -1)
       return;
     
-    Configuration *configuration = (*m_configuration);
     wxDC *dc = configuration->GetDC();
     // draw a thick line for 'page break'
     // and return
@@ -906,66 +974,23 @@ void GroupCell::Draw(wxPoint point)
       dc->DrawLine(0, y, (*m_configuration)->GetCanvasSize().GetWidth(), y);
       return;
     }
-
-    if (configuration->ShowBrackets())
-      DrawBracket();
     
     wxRect rect = GetRect(false);
-
+    
     if(configuration->GetIndent() < rect.GetRight())
     {
       if(rect.GetLeft() <= configuration->GetCellBracketWidth())
         rect.SetLeft(configuration->GetIndent());
       
-      //
-      // Paint background if we have a text cell
-      //
-      if (m_groupType == GC_TYPE_TEXT )
-      {
-        int y = rect.GetY();
-
-        if (m_height > 0 && m_width > 0 && y >= 0)
-        {
-          wxBrush br(configuration->GetColor(TS_TEXT_BACKGROUND));
-          dc->SetBrush(br);
-          wxPen pen(configuration->GetColor(TS_TEXT_BACKGROUND));
-          dc->SetPen(pen);
-          rect.SetWidth((*m_configuration)->GetCanvasSize().GetWidth());
-          if (InUpdateRegion(rect))
-            dc->DrawRectangle(CropToUpdateRegion(rect));
-        }
-      }
       //
       // Draw input and output
       //
       SetPen();
       wxPoint in(point);
 
-      if ((configuration->ShowCodeCells()) ||
-          (m_groupType != GC_TYPE_CODE))
+      if ((m_output != NULL) && !m_hide)
       {
-        configuration->Outdated(false);
-        int labelWidth = Scale_Px(configuration->GetLabelWidth());
-        if(m_inputLabel)
-        {
-          m_inputLabel->Draw(in);
-          labelWidth = MAX(labelWidth, m_inputLabel->GetWidth());
-        }
-        EditorCell *input = GetInput();
-        if(input)
-          input->Draw(
-            wxPoint(
-              in.x + labelWidth,
-              in.y
-              )
-            );
-        if (m_groupType == GC_TYPE_CODE && m_inputLabel->m_next)
-          configuration->Outdated((dynamic_cast<EditorCell *>(m_inputLabel->m_next))->ContainsChanges());
-      }
-
-      if (m_output != NULL && !m_hide)
-      {
-        MathCell *tmp = m_output;
+        Cell *tmp = m_output;
         int drop = tmp->GetMaxDrop();
         if ((configuration->ShowCodeCells()) ||
             (m_groupType != GC_TYPE_CODE))
@@ -975,26 +1000,17 @@ void GroupCell::Draw(wxPoint point)
         m_outputRect.y = in.y - m_output->GetMaxCenter();
         m_outputRect.x = in.x;
 
+        in.x += GetLineIndent(tmp);
         while (tmp != NULL)
         {         
-          tmp->SetCurrentPoint(in);
-
           tmp->Draw(in);
           if ((tmp->m_nextToDraw != NULL) && (tmp->m_nextToDraw->BreakLineHere()))
             {
               if (tmp->m_nextToDraw->m_bigSkip)
                 in.y += MC_LINE_SKIP;
  
-              in.x = point.x;
-              if(
-                (tmp->m_nextToDraw->GetStyle() != TS_LABEL) &&
-                (tmp->m_nextToDraw->GetStyle() != TS_USERLABEL) &&
-                (tmp->m_nextToDraw->GetStyle() != TS_MAIN_PROMPT) &&
-                (tmp->m_nextToDraw->GetStyle() != TS_OTHER_PROMPT) &&
-                configuration->IndentMaths()
-                )
-                in.x += Scale_Px(configuration->GetLabelWidth()) + MC_TEXT_PADDING;
-              
+              in.x = point.x + GetLineIndent(tmp->m_nextToDraw);              
+
               in.y += drop + tmp->m_nextToDraw->GetMaxCenter();
               drop = tmp->m_nextToDraw->GetMaxDrop();
             }
@@ -1004,12 +1020,55 @@ void GroupCell::Draw(wxPoint point)
           tmp = tmp->m_nextToDraw;
         }
       }
+      if ((configuration->ShowCodeCells()) ||
+          (m_groupType != GC_TYPE_CODE))
+      {
+        in = point;
+        
+        configuration->Outdated(false);
+
+        EditorCell *input = GetInput();
+        if(input)
+        {
+          in = point;
+          input->Draw(
+            wxPoint(
+              in.x + GetInputIndent(),
+              in.y
+              )
+            );
+        }
+        
+        if(GetPrompt() != NULL)
+          GetPrompt()->Draw(point);
+        
+        if (m_groupType == GC_TYPE_CODE && m_inputLabel->m_next)
+          configuration->Outdated((dynamic_cast<EditorCell *>(m_inputLabel->m_next))->ContainsChanges());
+      }
     }
     configuration->Outdated(false); 
     UnsetPen();
   }
 }
 
+int GroupCell::GetLineIndent(Cell *cell)
+{
+  int indent = 0;
+
+  if(cell != NULL)
+  {
+    if(
+      (cell->GetStyle() != TS_LABEL) &&
+      (cell->GetStyle() != TS_USERLABEL) &&
+      (cell->GetStyle() != TS_MAIN_PROMPT) &&
+      (cell->GetStyle() != TS_OTHER_PROMPT) &&
+      (*m_configuration)->IndentMaths()
+      )
+      indent += Scale_Px((*m_configuration)->GetLabelWidth()) + 2 * MC_TEXT_PADDING;
+  }
+  return indent;
+}
+
 void GroupCell::CellUnderPointer(GroupCell *cell)
 {
   if (m_cellPointers->m_groupCellUnderPointer != cell)
@@ -1100,8 +1159,8 @@ void GroupCell::DrawBracket()
           configuration->GetCellBracketWidth(),
           rect.GetHeight() + 5
   );
-  if (MathCell::InUpdateRegion(rect))
-    dc->DrawRectangle(MathCell::CropToUpdateRegion(rect));
+  if (Cell::InUpdateRegion(rect))
+    dc->DrawRectangle(Cell::CropToUpdateRegion(rect));
 
   //
   // Mark groupcells currently in queue.
@@ -1126,11 +1185,11 @@ void GroupCell::DrawBracket()
             rect.GetTop() - 2,
             configuration->GetCellBracketWidth(),
             rect.GetHeight() + 5);
-    if (MathCell::InUpdateRegion(rect))
+    if (Cell::InUpdateRegion(rect))
       dc->DrawRectangle(rect);
   }
 
-  MathCell *editable = GetEditable();
+  Cell *editable = GetEditable();
   if (editable != NULL && editable->IsActive())
   {
     drawBracket = true;
@@ -1158,50 +1217,104 @@ void GroupCell::DrawBracket()
     int bracketWidth = configuration->GetCellBracketWidth() - configuration->GetDefaultLineWidth();
     if (IsFoldable())
     { // draw the square that allows hiding and unhiding the cell
-      wxPoint *points = new wxPoint[4];
-      points[0].x = m_currentPoint.x - bracketWidth;
-      points[0].y = m_currentPoint.y - m_center;
-      points[1].x = m_currentPoint.x - bracketWidth;
-      points[1].y = m_currentPoint.y - m_center + bracketWidth;
-      points[2].x = m_currentPoint.x - configuration->GetDefaultLineWidth();
-      points[2].y = m_currentPoint.y - m_center + bracketWidth;
-      points[3].x = m_currentPoint.x - configuration->GetDefaultLineWidth();
-      points[3].y = m_currentPoint.y - m_center;
-      adc->DrawPolygon(4, points);
-      delete[] points;
+      wxPointList points;
+      points.DeleteContents(true);
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth,
+          m_currentPoint.y - m_center
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth,
+          m_currentPoint.y - m_center + bracketWidth
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - configuration->GetDefaultLineWidth(),
+          m_currentPoint.y - m_center + bracketWidth
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - configuration->GetDefaultLineWidth(),
+          m_currentPoint.y - m_center
+          )
+        );
+      adc->DrawPolygon(&points);
     }
     else
-    { // draw a the triangle that allows hiding and unhiding the cell
-      wxPoint *points = new wxPoint[3];
-      points[0].x = m_currentPoint.x - bracketWidth;
-      points[0].y = m_currentPoint.y - m_center + configuration->GetDefaultLineWidth() / 2;
-      points[1].x = m_currentPoint.x - bracketWidth;
-      points[1].y = m_currentPoint.y - m_center + bracketWidth - configuration->GetDefaultLineWidth() / 2;
-      points[2].x = m_currentPoint.x - configuration->GetDefaultLineWidth();
-      points[2].y = m_currentPoint.y - m_center + configuration->GetDefaultLineWidth() / 2;
-      adc->DrawPolygon(3, points);
-      delete[] points;
+    { 
+      wxPointList points;
+      points.DeleteContents(true);
+      // draw the triangle that allows hiding and unhiding the cell
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+          m_currentPoint.y - m_center + bracketWidth - configuration->GetDefaultLineWidth() / 2
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - configuration->GetDefaultLineWidth(),
+          m_currentPoint.y - m_center + configuration->GetDefaultLineWidth() / 2
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+          m_currentPoint.y - m_center + configuration->GetDefaultLineWidth() / 2
+          )
+        );
 
-      // The vertical line at the back of the bracket
-      adc->DrawLine(m_currentPoint.x - bracketWidth,
-                  m_currentPoint.y - m_center + configuration->GetDefaultLineWidth() / 2,
-                  m_currentPoint.x - bracketWidth,
-                  m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth());
-      // bottom horizontal line
-      adc->DrawLine(m_currentPoint.x - bracketWidth,
-                  m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth(),
-                  m_currentPoint.x - configuration->GetDefaultLineWidth(),
-                  m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth());
-      // middle horizontal
+      // The rest of the bracket
       if (configuration->ShowCodeCells() && m_groupType == GC_TYPE_CODE && m_output != NULL && !m_hide)
       {
-        adc->DrawLine(m_currentPoint.x - bracketWidth / 2,
-                    m_currentPoint.y - m_center + m_inputLabel->GetMaxHeight() +
-                    configuration->GetDefaultLineWidth() / 2,
-                    m_currentPoint.x - bracketWidth,
-                    m_currentPoint.y - m_center + m_inputLabel->GetMaxHeight() +
-                    configuration->GetDefaultLineWidth() / 2);
+        points.Append(
+          new wxPoint(
+            m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+            m_currentPoint.y - m_center + m_inputLabel->GetMaxHeight()
+            )
+          );
+        points.Append(
+          new wxPoint(
+            m_currentPoint.x - bracketWidth / 2 + configuration->GetDefaultLineWidth() / 2,
+            m_currentPoint.y - m_center + m_inputLabel->GetMaxHeight()
+            )
+          );
+        points.Append(
+          new wxPoint(
+            m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+            m_currentPoint.y - m_center + m_inputLabel->GetMaxHeight()
+            )
+          );
       }
+      
+      // The remaining part of the vertical line at the back
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+          m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth()
+          )
+        );
+      // The horizontal line at the bottom
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - configuration->GetDefaultLineWidth(),
+          m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth()
+          )
+        );
+      points.Append(
+        new wxPoint(
+          m_currentPoint.x - bracketWidth + configuration->GetDefaultLineWidth() / 2,
+          m_currentPoint.y - m_center + m_height - configuration->GetDefaultLineWidth()
+          )
+        );
+        
+      adc->DrawPolygon(&points);
+
     }
   }
 }
@@ -1237,7 +1350,7 @@ wxString GroupCell::ToString()
 
   if (m_output != NULL && !m_hide)
   {
-    MathCell *tmp = m_output;
+    Cell *tmp = m_output;
     bool firstCell = true;
     while (tmp != NULL)
     {
@@ -1300,7 +1413,7 @@ wxString GroupCell::ToRTF()
   if (GetEditable() != NULL)
     retval += GetEditable()->ToRTF();
 
-  MathCell *out = GetLabel();
+  Cell *out = GetLabel();
   if (out != NULL)
   {
     retval += out->ListToRTF(true);
@@ -1322,7 +1435,7 @@ wxString GroupCell::ToTeX(wxString imgDir, wxString filename, int *imgCounter)
     case GC_TYPE_IMAGE:
       if (imgDir != wxEmptyString)
       {
-        MathCell *copy = m_output->Copy();
+        Cell *copy = m_output->Copy();
         (*imgCounter)++;
         wxString image = filename + wxString::Format(wxT("_%d"), *imgCounter);
         wxString file = imgDir + wxT("/") + image + wxT(".") + dynamic_cast<ImgCell *>(copy)->GetExtension();
@@ -1424,7 +1537,7 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename, int *imgCo
     if (imgCounter == NULL)
       str += wxT("\\definecolor{labelcolor}{RGB}{100,0,0}\n");
 
-    MathCell *tmp = m_output;
+    Cell *tmp = m_output;
 
     bool mathMode = false;
 
@@ -1489,7 +1602,7 @@ wxString GroupCell::ToTeXCodeCell(wxString imgDir, wxString filename, int *imgCo
   return str;
 }
 
-wxString GroupCell::ToTeXImage(MathCell *tmp, wxString imgDir, wxString filename, int *imgCounter)
+wxString GroupCell::ToTeXImage(Cell *tmp, wxString imgDir, wxString filename, int *imgCounter)
 {
   wxASSERT_MSG((imgCounter != NULL), _("Bug: No image counter to write to!"));
   if (imgCounter == NULL) return wxEmptyString;
@@ -1498,7 +1611,7 @@ wxString GroupCell::ToTeXImage(MathCell *tmp, wxString imgDir, wxString filename
 
   if (imgDir != wxEmptyString)
   {
-    MathCell *copy = tmp->Copy();
+    Cell *copy = tmp->Copy();
     (*imgCounter)++;
     wxString image = filename + wxString::Format(wxT("_%d"), *imgCounter);
     if (!wxDirExists(imgDir))
@@ -1556,7 +1669,7 @@ wxString GroupCell::ToXML()
         // In theory the attribute should be saved and read verbatim, with the exception
         // of the characters XML wants to be quoted. In reality wxWidget's newline handling
         // seems to be broken => escape newlines.
-        wxString answer = MathCell::XMLescape(*it);
+        wxString answer = Cell::XMLescape(*it);
         answer.Replace(wxT("\n"),wxT("&#10;"));
         str += wxString::Format(wxT(" answer%i=\""),i) + answer + wxT("\"");
       }
@@ -1607,8 +1720,8 @@ wxString GroupCell::ToXML()
     str += wxT(" hide=\"true\"");
   str += wxT(">\n");
 
-  MathCell *input = GetInput();
-  MathCell *output = GetLabel();
+  Cell *input = GetInput();
+  Cell *output = GetLabel();
   // write contents
   switch (m_groupType)
   {
@@ -1654,7 +1767,7 @@ wxString GroupCell::ToXML()
       break;
     default:
     {
-      MathCell *tmp = output;
+      Cell *tmp = output;
       while (tmp != NULL)
       {
         str += tmp->ListToXML();
@@ -1669,7 +1782,7 @@ wxString GroupCell::ToXML()
 }
 
 void GroupCell::SelectRectGroup(wxRect &rect, wxPoint &one, wxPoint &two,
-                                MathCell **first, MathCell **last)
+                                Cell **first, Cell **last)
 {
   Configuration *configuration = (*m_configuration);
 
@@ -1695,7 +1808,7 @@ void GroupCell::SelectRectGroup(wxRect &rect, wxPoint &one, wxPoint &two,
   }
 }
 
-void GroupCell::SelectInner(wxRect &rect, MathCell **first, MathCell **last)
+void GroupCell::SelectInner(wxRect &rect, Cell **first, Cell **last)
 {
   *first = NULL;
   *last = NULL;
@@ -1712,7 +1825,7 @@ void GroupCell::SelectInner(wxRect &rect, MathCell **first, MathCell **last)
   }
 }
 
-void GroupCell::SelectPoint(wxPoint &point, MathCell **first, MathCell **last)
+void GroupCell::SelectPoint(wxPoint &point, Cell **first, Cell **last)
 {
   *first = NULL;
   *last = NULL;
@@ -1724,12 +1837,12 @@ void GroupCell::SelectPoint(wxPoint &point, MathCell **first, MathCell **last)
 }
 
 void GroupCell::SelectRectInOutput(wxRect &rect, wxPoint &one, wxPoint &two,
-                                   MathCell **first, MathCell **last)
+                                   Cell **first, Cell **last)
 {
   if (m_hide)
     return;
 
-  MathCell *tmp;
+  Cell *tmp;
   wxPoint start, end;
 
   if (one.y < two.y || (one.y == two.y && one.x < two.x))
@@ -1765,7 +1878,7 @@ void GroupCell::SelectRectInOutput(wxRect &rect, wxPoint &one, wxPoint &two,
     if ((*first)->GetCurrentY() != (*last)->GetCurrentY())
     {
       tmp = *last;
-      MathCell *curr;
+      Cell *curr;
 
       // Find the first cell in selection
       while (*first != tmp &&
@@ -1807,7 +1920,7 @@ wxString GroupCell::GetToolTip(const wxPoint &point)
   if (m_hide)
     return retval;
   
-  MathCell *tmp = m_output;
+  Cell *tmp = m_output;
   while (tmp != NULL)
   {
 
@@ -1853,37 +1966,43 @@ EditorCell *GroupCell::GetEditable()
   }
 }
 
-void GroupCell::BreakLines(int fullWidth)
+void GroupCell::BreakLines()
 {
-  BreakLines(m_output, fullWidth);
+  BreakLines(m_output);
 }
 
-void GroupCell::BreakLines(MathCell *cell, int fullWidth)
+void GroupCell::BreakLines(Cell *cell)
 {
+  int fullWidth = (*m_configuration)->GetClientWidth();
   Configuration *configuration = (*m_configuration);
-  int currentWidth = configuration->GetIndent();
+  int currentWidth = GetLineIndent(cell);
+  fullWidth -= configuration->GetIndent();
 
-  MathCell *tmp = cell;
-
-  while (tmp != NULL && !m_hide)
+  // Don't let the layout degenerate for small window widths
+  if (fullWidth < Scale_Px(150)) fullWidth = Scale_Px(150);
+  
+  while (cell != NULL && !m_hide)
   {
-    tmp->ResetData();
-    tmp->BreakLine(false);
-    if (!tmp->m_isBrokenIntoLines)
+    cell->ResetData();
+    cell->BreakLine(false);
+    if (!cell->m_isBrokenIntoLines)
     {
-      if (tmp->BreakLineHere() || (currentWidth + tmp->GetWidth() >= fullWidth))
+      if (cell->BreakLineHere() || (currentWidth + cell->GetWidth() >= fullWidth))
       {
-        currentWidth = configuration->GetIndent() + tmp->GetWidth();
-        tmp->BreakLine(true);
+        cell->BreakLine(true);
+        Cell *nextCell = cell;
+        if(cell->m_nextToDraw)
+          nextCell = cell->m_nextToDraw;
+        currentWidth = GetLineIndent(nextCell) + cell->GetWidth();
       }
       else
-        currentWidth += tmp->GetWidth();
+        currentWidth += cell->GetWidth();
     }
-    tmp = tmp->m_nextToDraw;
+    cell = cell->m_nextToDraw;
   }
 }
 
-void GroupCell::SelectOutput(MathCell **start, MathCell **end)
+void GroupCell::SelectOutput(Cell **start, Cell **end)
 {
   if (m_hide)
     return;
@@ -1907,17 +2026,18 @@ void GroupCell::SelectOutput(MathCell **start, MathCell **end)
     *end = *start = NULL;
 }
 
-void GroupCell::BreakUpCells(int fontsize, int clientWidth)
+void GroupCell::BreakUpCells()
 {
-  BreakUpCells(m_output, fontsize, clientWidth);
+  BreakUpCells(m_output);
 }
 
-void GroupCell::BreakUpCells(MathCell *cell, int WXUNUSED(fontsize), int clientWidth)
+void GroupCell::BreakUpCells(Cell *cell)
 {
+  int clientWidth = (*m_configuration)->GetClientWidth();
   if(cell == NULL)
     return;
 
-  MathCell *tmp = cell;
+  Cell *tmp = cell;
 
   bool lineHeightsChanged = false;
     
@@ -1946,7 +2066,7 @@ void GroupCell::BreakUpCells(MathCell *cell, int WXUNUSED(fontsize), int clientW
 
 void GroupCell::UnBreakUpCells()
 {
-  MathCell *tmp = m_output;
+  Cell *tmp = m_output;
   while (tmp != NULL)
   {
     if (tmp->m_isBrokenIntoLines)
@@ -2097,13 +2217,13 @@ GroupCell *GroupCell::Unfold()
   if (!IsFoldable() || !m_hiddenTree)
     return NULL;
 
-  MathCell *next = m_next;
+  Cell *next = m_next;
 
   // sew together this cell with m_hiddenTree
   m_next = m_nextToDraw = m_hiddenTree;
   m_hiddenTree->m_previous = m_hiddenTree->m_previousToDraw = this;
 
-  MathCell *tmp = m_hiddenTree;
+  Cell *tmp = m_hiddenTree;
   while (tmp->m_next)
     tmp = tmp->m_next;
   // tmp holds the last element of m_hiddenTree
@@ -2270,7 +2390,7 @@ void GroupCell::Number(int &section, int &subsection, int &subsubsection, int &h
   }
 }
 
-bool GroupCell::IsMainInput(MathCell *active)
+bool GroupCell::IsMainInput(Cell *active)
 {
   return m_inputLabel->m_next != NULL && active == m_inputLabel->m_next;
 }
@@ -2321,7 +2441,7 @@ wxAccStatus GroupCell::GetDescription(int childId, wxString *description)
   }
   else
   {
-    MathCell *cell = NULL;
+    Cell *cell = NULL;
     if (GetChild(childId, &cell) == wxACC_OK)
     {
       return cell->GetDescription(0, description);
@@ -2337,8 +2457,8 @@ wxAccStatus GroupCell::GetLocation(wxRect &rect, int elementId)
 {
   if(elementId == 0)
   {
-    rect = wxRect(GetRect().GetTopLeft()     + m_visibleRegion.GetTopLeft(),
-                  GetRect().GetBottomRight() + m_visibleRegion.GetTopLeft());
+    rect = wxRect(GetRect().GetTopLeft()     + (*m_configuration)->GetVisibleRegion().GetTopLeft(),
+                  GetRect().GetBottomRight() + (*m_configuration)->GetVisibleRegion().GetTopLeft());
     
     // Our GroupCell handles the hcaret below the cell, as well as its contents
     rect.SetBottom(rect.GetBottom()+(*m_configuration)->GetGroupSkip());
@@ -2352,16 +2472,16 @@ wxAccStatus GroupCell::GetLocation(wxRect &rect, int elementId)
       rect.SetTop(0);
     if(rect.GetLeft() < 0)
       rect.SetLeft(0);
-    if(rect.GetBottom() > m_visibleRegion.GetWidth())
-      rect.SetBottom(m_visibleRegion.GetWidth());
-    if(rect.GetRight() > m_visibleRegion.GetHeight())
-      rect.SetRight(m_visibleRegion.GetHeight());
-    rect = wxRect(rect.GetTopLeft()+m_worksheetPosition,rect.GetBottomRight()+m_worksheetPosition);
+    if(rect.GetBottom() > (*m_configuration)->GetVisibleRegion().GetWidth())
+      rect.SetBottom((*m_configuration)->GetVisibleRegion().GetWidth());
+    if(rect.GetRight() > (*m_configuration)->GetVisibleRegion().GetHeight())
+      rect.SetRight((*m_configuration)->GetVisibleRegion().GetHeight());
+    rect = wxRect(rect.GetTopLeft()+(*m_configuration)->GetWorksheetPosition(),rect.GetBottomRight()+(*m_configuration)->GetWorksheetPosition());
     return wxACC_OK;
   }
   else
   {
-    MathCell *child = NULL;
+    Cell *child = NULL;
 	if (GetChild(elementId, &child) == wxACC_OK)
 		return child->GetLocation(rect, 0);
   }
