@@ -23,25 +23,25 @@
 /*! \file
   This file declares the class LimitCell
 
-  LimitCell is the MathCell type that represents maxima's <code>limit()</code> command.
+  LimitCell is the Cell type that represents maxima's <code>limit()</code> command.
 */
 
 #ifndef LIMITCELL_H
 #define LIMITCELL_H
 
-#include "MathCell.h"
+#include "Cell.h"
 #include "TextCell.h"
 
-class LimitCell : public MathCell
+class LimitCell : public Cell
 {
 public:
-  LimitCell(MathCell *parent, Configuration **config, CellPointers *cellPointers);
+  LimitCell(Cell *parent, Configuration **config, CellPointers *cellPointers);
 
   ~LimitCell();
 
-  std::list<MathCell *> GetInnerCells();
+  std::list<Cell *> GetInnerCells();
 
-  MathCell *Copy();
+  Cell *Copy();
 
   void RecalculateHeight(int fontsize);
 
@@ -49,11 +49,11 @@ public:
 
   virtual void Draw(wxPoint point);
 
-  void SetBase(MathCell *base);
+  void SetBase(Cell *base);
 
-  void SetUnder(MathCell *under);
+  void SetUnder(Cell *under);
 
-  void SetName(MathCell *name);
+  void SetName(Cell *name);
 
   wxString ToString();
 
@@ -65,20 +65,20 @@ public:
 
   wxString ToMathML();
 
-  void SetGroup(MathCell *parent);
+  void SetGroup(Cell *parent);
   void Unbreak();
   bool BreakUp();
 
 protected:
-  MathCell *m_name;
+  Cell *m_name;
   TextCell *m_open;
-  MathCell *m_base;
+  Cell *m_base;
   TextCell *m_comma;
-  MathCell *m_under;
+  Cell *m_under;
   TextCell *m_close;
-  MathCell *m_name_last;
-  MathCell *m_base_last;
-  MathCell *m_under_last;
+  Cell *m_name_last;
+  Cell *m_base_last;
+  Cell *m_under_last;
 };
 
 #endif // LIMITCELL_H
