@@ -23,13 +23,13 @@
 /*! \file
   This file defines the class MatrCell
 
-  MatrCell is the MathCell type that represents matrices and matrix-like 
+  MatrCell is the Cell type that represents matrices and matrix-like 
   elements like the table_form command.
 */
 
 #include "MatrCell.h"
 
-MatrCell::MatrCell(MathCell *parent, Configuration **config, CellPointers *cellPointers) : MathCell(parent, config)
+MatrCell::MatrCell(Cell *parent, Configuration **config, CellPointers *cellPointers) : Cell(parent, config)
 {
   m_cellPointers = cellPointers;
   m_matWidth = 0;
@@ -40,7 +40,7 @@ MatrCell::MatrCell(MathCell *parent, Configuration **config, CellPointers *cellP
   m_rowNames = m_colNames = false;
 }
 
-void MatrCell::SetGroup(MathCell *parent)
+void MatrCell::SetGroup(Cell *parent)
 {
   m_group = parent;
   for (unsigned int i = 0; i < m_cells.size(); i++)
@@ -50,7 +50,7 @@ void MatrCell::SetGroup(MathCell *parent)
   }
 }
 
-MathCell *MatrCell::Copy()
+Cell *MatrCell::Copy()
 {
   MatrCell *tmp = new MatrCell(m_group, m_configuration, m_cellPointers);
   CopyData(this, tmp);
@@ -61,9 +61,10 @@ MathCell *MatrCell::Copy()
   tmp->m_colNames = m_colNames;
   tmp->m_matWidth = m_matWidth;
   tmp->m_matHeight = m_matHeight;
-  for (int i = 0; i < m_matWidth * m_matHeight; i++)
-    (tmp->m_cells).push_back(m_cells[i]->CopyList());
-
+  for (unsigned int i = 0; i < m_matWidth * m_matHeight; i++)
+    if(i < m_cells.size())
+      (tmp->m_cells).push_back(m_cells[i]->CopyList());
+  
   return tmp;
 }
 
@@ -77,9 +78,9 @@ MatrCell::~MatrCell()
   MarkAsDeleted();
 }
 
-std::list<MathCell *> MatrCell::GetInnerCells()
+std::list<Cell *> MatrCell::GetInnerCells()
 {
-  std::list<MathCell *> innerCells;
+  std::list<Cell *> innerCells;
   for (unsigned int i = 0; i < m_cells.size(); i++)
     if(m_cells[i])
       innerCells.push_back(m_cells[i]);
@@ -90,22 +91,23 @@ std::list<MathCell *> MatrCell::GetInnerCells()
 
 void MatrCell::RecalculateWidths(int fontsize)
 {
-  MathCell::RecalculateWidths(fontsize);
-  for (int i = 0; i < m_matWidth * m_matHeight; i++)
+  Cell::RecalculateWidths(fontsize);
+  for (unsigned int i = 0; i < m_cells.size(); i++)
   {
     m_cells[i]->RecalculateWidthsList(MAX(MC_MIN_SIZE, fontsize - 2));
   }
   m_widths.clear();
-  for (int i = 0; i < m_matWidth; i++)
+  for (unsigned int i = 0; i < m_matWidth; i++)
   {
     m_widths.push_back(0);
-    for (int j = 0; j < m_matHeight; j++)
+    for (unsigned int j = 0; j < m_matHeight; j++)
     {
-      m_widths[i] = MAX(m_widths[i], m_cells[m_matWidth * j + i]->GetFullWidth());
+      if((m_matWidth * j + i)<m_cells.size())
+        m_widths[i] = MAX(m_widths[i], m_cells[m_matWidth * j + i]->GetFullWidth());
     }
   }
   m_width = 0;
-  for (int i = 0; i < m_matWidth; i++)
+  for (unsigned int i = 0; i < m_matWidth; i++)
   {
     m_width += (m_widths[i] + Scale_Px(10));
   }
@@ -116,25 +118,26 @@ void MatrCell::RecalculateWidths(int fontsize)
 
 void MatrCell::RecalculateHeight(int fontsize)
 {
-  MathCell::RecalculateHeight(fontsize);
-  for (int i = 0; i < m_matWidth * m_matHeight; i++)
+  Cell::RecalculateHeight(fontsize);
+  for (unsigned int i = 0; i < m_cells.size(); i++)
   {
     m_cells[i]->RecalculateHeightList(MAX(MC_MIN_SIZE, fontsize - 2));
   }
   m_centers.clear();
   m_drops.clear();
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     m_centers.push_back(0);
     m_drops.push_back(0);
-    for (int j = 0; j < m_matWidth; j++)
-    {
-      m_centers[i] = MAX(m_centers[i], m_cells[m_matWidth * i + j]->GetMaxCenter());
-      m_drops[i] = MAX(m_drops[i], m_cells[m_matWidth * i + j]->GetMaxDrop());
-    }
+    for (unsigned int j = 0; j < m_matWidth; j++)
+      if(m_matWidth * i + j < m_cells.size())
+      {
+        m_centers[i] = MAX(m_centers[i], m_cells[m_matWidth * i + j]->GetMaxCenter());
+        m_drops[i] = MAX(m_drops[i], m_cells[m_matWidth * i + j]->GetMaxDrop());
+      }
   }
   m_height = 0;
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     m_height += (m_centers[i] + m_drops[i] + Scale_Px(10));
   }
@@ -145,7 +148,7 @@ void MatrCell::RecalculateHeight(int fontsize)
 
 void MatrCell::Draw(wxPoint point)
 {
-  MathCell::Draw(point);
+  Cell::Draw(point);
   if (DrawThisCell(point) && InUpdateRegion())
   {
     Configuration *configuration = (*m_configuration);
@@ -153,16 +156,19 @@ void MatrCell::Draw(wxPoint point)
     wxPoint mp;
     mp.x = point.x + Scale_Px(5);
     mp.y = point.y - m_center;
-    for (int i = 0; i < m_matWidth; i++)
+    for (unsigned int i = 0; i < m_matWidth; i++)
     {
       mp.y = point.y - m_center + Scale_Px(5);
-      for (int j = 0; j < m_matHeight; j++)
+      for (unsigned int j = 0; j < m_matHeight; j++)
       {
-        mp.y += m_centers[j];
-        wxPoint mp1(mp);
-        mp1.x = mp.x + (m_widths[i] - m_cells[j * m_matWidth + i]->GetFullWidth()) / 2;
-        m_cells[j * m_matWidth + i]->DrawList(mp1);
-        mp.y += (m_drops[j] + Scale_Px(10));
+        if((j * m_matWidth + i) < m_cells.size())
+          {
+            mp.y += m_centers[j];
+            wxPoint mp1(mp);
+            mp1.x = mp.x + (m_widths[i] - m_cells[j * m_matWidth + i]->GetFullWidth()) / 2;
+            m_cells[j * m_matWidth + i]->DrawList(mp1);
+            mp.y += (m_drops[j] + Scale_Px(10));
+          }
       }
       mp.x += (m_widths[i] + Scale_Px(10));
     }
@@ -269,10 +275,10 @@ void MatrCell::Draw(wxPoint point)
 wxString MatrCell::ToString()
 {
   wxString s = wxT("matrix(\n");
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     s += wxT("\t\t[");
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
     {
       s += m_cells[i * m_matWidth + j]->ListToString();
       if (j < m_matWidth - 1)
@@ -302,13 +308,13 @@ wxString MatrCell::ToTeX()
   else
   {
     s = wxT("\\begin{array}{");
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
       s += wxT("c");
     s += wxT("}");
   }
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
     {
       s += m_cells[i * m_matWidth + j]->ListToTeX();
       if (j < m_matWidth - 1)
@@ -336,10 +342,10 @@ wxString MatrCell::ToMathML()
     retval = wxT("<mrow><mo>(</mo><mrow>");
   retval += wxT("<mtable>");
 
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     retval += wxT("<mtr>");
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
       retval += wxT("<mtd>") + m_cells[i * m_matWidth + j]->ListToMathML() + wxT("</mtd>");
     retval += wxT("</mtr>");
   }
@@ -364,10 +370,10 @@ wxString MatrCell::ToOMML()
   
   retval += wxT("<m:e><m:m>");
 
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     retval += wxT("<m:mr>");
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
       retval += wxT("<m:e>") + m_cells[i * m_matWidth + j]->ListToOMML() + wxT("</m:e>");
     retval += wxT("</m:mr>");
   }
@@ -394,10 +400,10 @@ wxString MatrCell::ToXML()
   else
     s = wxT("<tb") +flags +wxT(">");
 
-  for (int i = 0; i < m_matHeight; i++)
+  for (unsigned int i = 0; i < m_matHeight; i++)
   {
     s += wxT("<mtr>");
-    for (int j = 0; j < m_matWidth; j++)
+    for (unsigned int j = 0; j < m_matWidth; j++)
       s += wxT("<mtd>") + m_cells[i * m_matWidth + j]->ListToXML() + wxT("</mtd>");
     s += wxT("</mtr>");
   }
