@@ -18,6 +18,7 @@
 //  along with this program; if not, write to the Free Software
 //  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 //
+//  SPDX-License-Identifier: GPL-2.0+
 
 /*!\file
   This file defines the contents of the class StatusBar that represents wxMaxima's status bar.
@@ -55,8 +56,8 @@ StatusBar::StatusBar(wxWindow *parent, int id) : wxStatusBar(parent, id)
                               network_transmit_192_png,network_transmit_192_png_len
     );
   m_network_idle = GetImage("network-idle",
-                              network_idle_128_png,network_idle_128_png_len,
-                              network_idle_192_png,network_idle_192_png_len
+                            network_idle_128_png,network_idle_128_png_len,
+                            network_idle_192_png,network_idle_192_png_len
     );
   m_network_idle_inactive = wxBitmap(m_network_idle.ConvertToImage().ConvertToDisabled());
   m_network_receive = GetImage("network-receive",
@@ -95,16 +96,22 @@ void StatusBar::OnTimerEvent(wxTimerEvent &WXUNUSED(event))
   if (m_icon_shows_receive && m_icon_shows_transmit)
   {
     m_networkStatus->SetBitmap(m_network_transmit_receive);
+    if(m_maximaPercentage == 0)
+      m_maximaPercentage = -1;
   }
   if (m_icon_shows_receive && !m_icon_shows_transmit)
   {
     m_networkStatus->SetBitmap(m_network_receive);
     m_oldNetworkState = receive;
+    if(m_maximaPercentage == 0)
+      m_maximaPercentage = -1;
   }
   if (!m_icon_shows_receive && m_icon_shows_transmit)
   {
     m_networkStatus->SetBitmap(m_network_transmit);
     m_oldNetworkState = transmit;
+    if(m_maximaPercentage == 0)
+      m_maximaPercentage = -1;
   }
   if (!m_icon_shows_receive && !m_icon_shows_transmit)
   {
@@ -126,8 +133,8 @@ void StatusBar::NetworkStatus(networkState status)
     {
     case idle:
     {
-      if(status != m_oldNetworkState)
-        m_maximaPercentage = m_oldmaximaPercentage = -1;
+//      if(status != m_oldNetworkState)
+//        m_maximaPercentage = m_oldmaximaPercentage = -1;
       if(m_maximaPercentage != 0)
         m_networkStatus->SetBitmap(m_network_idle);
       else
@@ -196,8 +203,8 @@ wxBitmap StatusBar::GetImage(wxString name,
                           unsigned char *data_128, size_t len_128,
                           unsigned char *data_192, size_t len_192)
 {
-  double targetWidth = static_cast<double>(GetSize().GetHeight()) / wxGetDisplayPPI().y * wxGetDisplayPPI().x;
-  double targetHeight = static_cast<double>(GetSize().GetHeight());
+  double targetWidth = static_cast<double>(GetSize().GetHeight()) / wxGetDisplayPPI().y * wxGetDisplayPPI().x*GetContentScaleFactor();
+  double targetHeight = static_cast<double>(GetSize().GetHeight())*GetContentScaleFactor();
 
   wxBitmap bmp = wxArtProvider::GetBitmap(name, wxART_TOOLBAR, wxSize(targetWidth, targetHeight));
   wxImage img;
@@ -251,7 +258,11 @@ wxBitmap StatusBar::GetImage(wxString name,
 
   img.Rescale(targetWidth, targetHeight, wxIMAGE_QUALITY_HIGH);
 
-  return img;
+#if defined __WXMAC__
+  return wxBitmap(img,wxBITMAP_SCREEN_DEPTH,GetContentScaleFactor());
+#else
+  return wxBitmap(img,wxBITMAP_SCREEN_DEPTH);
+#endif
 }
 
 
