@@ -23,14 +23,14 @@
 /*! \file
   This file defines the class TextCell
 
-  TextCell is the MathCell type that is used in order to display text that is
+  TextCell is the Cell type that is used in order to display text that is
   contained in maxima's output.
  */
 
 #include "TextCell.h"
 #include "wx/config.h"
 
-TextCell::TextCell(MathCell *parent, Configuration **config, CellPointers *cellPointers, wxString text) : MathCell(parent, config)
+TextCell::TextCell(Cell *parent, Configuration **config, CellPointers *cellPointers, wxString text) : Cell(parent, config)
 {
   m_cellPointers = cellPointers;
   m_displayedDigits_old = -1;
@@ -43,7 +43,8 @@ TextCell::TextCell(MathCell *parent, Configuration **config, CellPointers *cellP
   SetValue(text);
   m_highlight = false;
   m_dontEscapeOpeningParenthesis = false;
-  m_initialToolTip = (*m_configuration)->GetDefaultMathCellToolTip();
+  m_initialToolTip = (*m_configuration)->GetDefaultCellToolTip();
+  m_fontsize_old = -1;
 }
 
 TextCell::~TextCell()
@@ -51,22 +52,23 @@ TextCell::~TextCell()
   MarkAsDeleted();
 }
 
-std::list<MathCell *> TextCell::GetInnerCells()
+std::list<Cell *> TextCell::GetInnerCells()
 {
-  std::list<MathCell *> innerCells;
+  std::list<Cell *> innerCells;
   return innerCells;
 }
 
-void TextCell::SetStyle(int style)
+void TextCell::SetStyle(TextStyle style)
 {
-  MathCell::SetStyle(style);
+  Cell::SetStyle(style);
   if ((m_text == wxT("gamma")) && (m_textStyle == TS_FUNCTION))
     m_displayedText = wxT("\x0393");
   if ((m_text == wxT("psi")) && (m_textStyle == TS_FUNCTION))
     m_displayedText = wxT("\x03A8");
   if((style == TS_LABEL) || (style == TS_USERLABEL)||
      (style == TS_MAIN_PROMPT) || (style == TS_OTHER_PROMPT))
-    m_forceBreakLine = true;
+    ForceBreakLineHere();
+  ResetSize();
 }
 
 void TextCell::SetValue(const wxString &text)
@@ -284,9 +286,10 @@ void TextCell::SetValue(const wxString &text)
     }
   }
   m_alt = m_altJs = false;
+  ResetSize();
 }
 
-MathCell *TextCell::Copy()
+Cell *TextCell::Copy()
 {
   TextCell *retval = new TextCell(m_group, m_configuration, m_cellPointers, wxEmptyString);
   CopyData(this, retval);
@@ -305,7 +308,10 @@ MathCell *TextCell::Copy()
 
 void TextCell::RecalculateWidths(int fontsize)
 {
-  MathCell::RecalculateWidths(fontsize);
+  if(fontsize != m_fontsize_old)
+    ResetSize();
+  m_fontsize_old = fontsize;
+  Cell::RecalculateWidths(fontsize);
   Configuration *configuration = (*m_configuration);
 
   bool recalculateNeeded = false;
@@ -349,8 +355,7 @@ void TextCell::RecalculateWidths(int fontsize)
     recalculateNeeded = true;
   }
 
-  if (m_height == -1 || m_width == -1 || configuration->ForceUpdate() ||
-      m_lastCalculationFontSize != fontsize)
+  if (m_height == -1 || m_width == -1 || configuration->FontChanged())
     recalculateNeeded = true;
 
   if(recalculateNeeded)
@@ -361,7 +366,7 @@ void TextCell::RecalculateWidths(int fontsize)
 
     // Labels and prompts are fixed width - adjust font size so that
     // they fit in
-    if ((m_textStyle == TS_LABEL) || (m_textStyle == TS_USERLABEL) || (m_textStyle == TS_MAIN_PROMPT))
+    if ((m_textStyle == TS_LABEL) || (m_textStyle == TS_USERLABEL) || (m_textStyle == TS_MAIN_PROMPT) || (m_textStyle == TS_OTHER_PROMPT))
     {
       wxString text = m_text;
 
@@ -387,7 +392,6 @@ void TextCell::RecalculateWidths(int fontsize)
       // We will decrease it before use
       m_fontSizeLabel = m_fontSize + 1;
       int labelWidth,labelHeight;
-      if (m_width < 1) m_width = 10;
       dc->GetTextExtent(text, &labelWidth, &labelHeight);
       wxASSERT_MSG((labelWidth > 0) || (m_displayedText == wxEmptyString),
                    _("Seems like something is broken with the maths font. Installing http://www.math.union.edu/~dpvc/jsmath/download/jsMath-fonts.html and checking \"Use JSmath fonts\" in the configuration dialogue should fix it."));
@@ -452,7 +456,7 @@ void TextCell::Draw(wxPoint point)
   {
     
     Configuration *configuration = (*m_configuration);
-    MathCell::Draw(point);
+    Cell::Draw(point);
     wxDC *dc = configuration->GetDC();
     
     if (m_width == -1 || m_height == -1 || m_fontSize != m_lastCalculationFontSize)
@@ -691,6 +695,8 @@ wxString TextCell::ToString()
         text += wxT("\t");
         break;
       }
+  default:
+  {}
   }
   if((m_next != NULL) && (m_next->BreakLine()))
     text += "\n";
@@ -1156,7 +1162,8 @@ wxString TextCell::ToMathML()
           text = wxT("i");
       }
     }
-    case TS_VARIABLE:
+    /* FALLTHRU */
+  case TS_VARIABLE:
     {
       bool keepPercent = (*m_configuration)->CheckKeepPercent();
 
@@ -1166,7 +1173,8 @@ wxString TextCell::ToMathML()
           text = wxT("\x03C0");
       }
     }
-    case TS_FUNCTION:
+    /* FALLTHRU */
+  case TS_FUNCTION:
       text = GetGreekStringUnicode();
       if (text == wxT("inf"))
         text = wxT("\x221e");
@@ -1238,7 +1246,8 @@ wxString TextCell::ToOMML()
           text = wxT("i");
       }
     }
-    case TS_VARIABLE:
+    /* FALLTHRU */
+  case TS_VARIABLE:
     {
       bool keepPercent = (*m_configuration)->CheckKeepPercent();
 
@@ -1248,7 +1257,8 @@ wxString TextCell::ToOMML()
           text = wxT("\x03C0");
       }
     }
-    case TS_FUNCTION:
+    /* FALLTHRU */
+  case TS_FUNCTION:
       text = GetGreekStringUnicode();
       if (text == wxT("inf"))
         text = wxT("\x221e");
