@@ -92,16 +92,6 @@ wxBitmap ToolBar::GetImage(wxString name,
     img = wxImage(invalidImage_xpm);
   }
 
-#if defined __WXMSW__
-#if wxCHECK_VERSION(3, 1, 1)
-  // MSW is notorious for having problems with transparent black pixels.
-  // Let's see if we can avoid these problems by converting the alpha
-  // channel to a mask even if that means we cannot antialias a transparent 
-  // and a colored pixel to a half-transparent one any more.
-  img.ConvertAlphaToMask();
-#endif
-#endif
-  
   img.Rescale(targetSize, targetSize, wxIMAGE_QUALITY_HIGH);
 #if defined __WXMAC__
   return wxBitmap(img,wxBITMAP_SCREEN_DEPTH,GetContentScaleFactor());
@@ -377,7 +367,7 @@ void ToolBar::SetDefaultCellStyle()
   }
 }
 
-int ToolBar::GetCellStyle()
+GroupType ToolBar::GetCellType()
 {
   switch(m_textStyle->GetSelection())
   {
