@@ -269,7 +269,7 @@ protected:
                          this file.
     \param keyword The keyword to show help for
   */
-  void ShowHTMLHelp(wxString helpfile, wxString otherhelpfile, wxString keyword);
+  void ShowHTMLHelp(wxString helpfile, wxString keyword = wxEmptyString);
 
   void CheckForUpdates(bool reportUpToDate = false);
 
@@ -367,15 +367,15 @@ protected:
     NULL, if there is no such line (for example if the appended object is 
     maths instead).
    */
-  TextCell *ConsoleAppend(wxString s, int type, wxString userLabel = wxEmptyString);        //!< append maxima output to console
-  void DoConsoleAppend(wxString s, int type, 
+  TextCell *ConsoleAppend(wxString s, CellType type, wxString userLabel = wxEmptyString);        //!< append maxima output to console
+  void DoConsoleAppend(wxString s, CellType  type, 
                        bool newLine = true, bool bigSkip = true, wxString userLabel = wxEmptyString);
 
   /*!Append one or more lines of ordinary unicode text to the console
 
     \return A pointer to the last line that was appended or NULL, if there is no such line
    */
-  TextCell *DoRawConsoleAppend(wxString s, int type); 
+  TextCell *DoRawConsoleAppend(wxString s, CellType  type); 
 
   /*! Spawn the "configure" menu.
 
@@ -639,10 +639,14 @@ protected:
   wxPrintData *m_printData;
   bool m_closing;
   wxString m_openFile;
+  //! The directory with maxima's temp files
   wxString m_maximaTempDir;
+  //! The directory with maxima's documentation
+  wxString m_maximaDocDir;
+  //! The directory with maxima's share files
+  wxString m_maximaShareDir;
   bool m_fileSaved;
   wxString m_chmhelpFile;
-  bool m_htmlHelpInitialized;
   wxString m_maximaVersion;
   wxString m_maximaArch;
   wxString m_lispVersion;
